OH_Input_GetAxisEventDisplayX

Function OH_Input_GetAxisEventDisplayX 

pub unsafe extern "C" fn OH_Input_GetAxisEventDisplayX(
    axisEvent: *const Input_AxisEvent,
    displayX: *mut f32,
) -> Input_Result
@brief Obtains the X coordinate of the axis event in the relative coordinate system with the upper-left corner of the specified screen as the origin.

@param axisEvent Axis event object. You can call {@link OH_Input_CreateAxisEvent()} to create an axis event object.
If the axis event object is no longer needed, destroy it by calling {@link OH_Input_DestroyAxisEvent()}. @param displayX Output parameter, returns the X coordinate of the axis event in the relative coordinate system with the upper left corner of the specified screen as the origin, in pixels (px). @return {@link INPUT_SUCCESS} if the operation is successful; {@link INPUT_PARAMETER_ERROR} if axisEvent or ** displayX** is null. @syscap SystemCapability.MultimodalInput.Input.Core @since 12