OH_Input_GetKeyCode

Function OH_Input_GetKeyCode 

pub unsafe extern "C" fn OH_Input_GetKeyCode(
    keyState: *const Input_KeyState,
) -> i32
@brief Obtains the key value of a key status enum object.

@param keyState Key status enum object. For details, see {@link Input_KeyStateAction}. @return Key value of the key status enum object. For details, see {@link Input_KeyStateAction}. @syscap SystemCapability.MultimodalInput.Input.Core @since 12