OH_Input_GetTouchEventDisplayY

Function OH_Input_GetTouchEventDisplayY 

pub unsafe extern "C" fn OH_Input_GetTouchEventDisplayY(
    touchEvent: *const Input_TouchEvent,
) -> i32
@brief Obtains the Y coordinate of the touch event in the relative coordinate system with the upper-left corner of the specified screen as the origin.

@param touchEvent TouchEvent object, which can be created through {@link OH_Input_CreateTouchEvent()}.
If the TouchEvent object is no longer needed, destroy it by calling {@link OH_Input_DestroyTouchEvent()}. @return The Y coordinate of the touch screen input event in the relative coordinate system with the upper left corner of the specified screen as the origin, in pixels (px). @syscap SystemCapability.MultimodalInput.Input.Core @since 12