OH_Input_SetKeyEventKeyCode

Function OH_Input_SetKeyEventKeyCode 

pub unsafe extern "C" fn OH_Input_SetKeyEventKeyCode(
    keyEvent: *mut Input_KeyEvent,
    keyCode: i32,
)
@brief Sets the key code value for a key event.

@param keyEvent KeyEvent object, which can be created through {@link OH_Input_CreateKeyEvent()}.
If the key event object is no longer needed, destroy it by calling {@link OH_Input_DestroyKeyEvent()}. @param keyCode Key value. For details, see {@link KeyCode}. @syscap SystemCapability.MultimodalInput.Input.Core @since 12