OH_Input_SetTouchEventActionTime

Function OH_Input_SetTouchEventActionTime 

pub unsafe extern "C" fn OH_Input_SetTouchEventActionTime(
    touchEvent: *mut Input_TouchEvent,
    actionTime: i64,
)
@brief Sets the time when the touch event occurs.

@param touchEvent TouchEvent object, which can be created through {@link OH_Input_CreateTouchEvent()}.
If the TouchEvent object is no longer needed, destroy it by calling {@link OH_Input_DestroyTouchEvent()}. @param actionTime Time when the touch screen input event occurred, indicating the number of microseconds elapsed since system startup, in microseconds (μs). @syscap SystemCapability.MultimodalInput.Input.Core @since 12