OH_Input_SetTouchEventDisplayX

Function OH_Input_SetTouchEventDisplayX 

pub unsafe extern "C" fn OH_Input_SetTouchEventDisplayX(
    touchEvent: *mut Input_TouchEvent,
    displayX: i32,
)
@brief Sets the X coordinate of the touch event in the relative coordinate system with the upper-left corner of the specified screen as the origin.

@param touchEvent TouchEvent object, which can be created through {@link OH_Input_CreateTouchEvent()}.
If the TouchEvent object is no longer needed, destroy it by calling {@link OH_Input_DestroyTouchEvent()}. @param displayX X coordinate of the touch screen input event in the relative coordinate system with the upper left corner of the specified screen as the origin, in pixels (px). @syscap SystemCapability.MultimodalInput.Input.Core @since 12