Skip to main content Crate ohos_multi_modal_input_sys Copy item path Source Input_AxisEvent Input_InterceptorEventCallback @brief Defines the structure for the interceptor of event callbacks,
including mouseCallback, touchCallback, and axisCallback.
@since 12 Input_InterceptorOptions Input_KeyEvent Input_KeyState Input_MouseEvent Input_TouchEvent OH_PixelmapNative @brief Define a Pixelmap struct type, used for pixelmap pointer controls. InputEvent_AxisAction_AXIS_ACTION_BEGIN The axis event begins.
@since 12 InputEvent_AxisAction_AXIS_ACTION_CANCEL The axis event is canceled.
@since 12 InputEvent_AxisAction_AXIS_ACTION_END The axis event ends.
@since 12 InputEvent_AxisAction_AXIS_ACTION_UPDATE The axis event is updated.
@since 12 InputEvent_AxisEventType_AXIS_EVENT_TYPE_PINCH @brief Two-finger pinch event. The value can be AXIS_TYPE_PINCH or AXIS_TYPE_ROTATE , both of which are
of the {@link InputEvent_AxisType} type. InputEvent_AxisEventType_AXIS_EVENT_TYPE_SCROLL @brief Scroll event. The value can be AXIS_TYPE_SCROLL_VERTICAL or AXIS_TYPE_SCROLL_HORIZONTAL , both of
which are of the {@link InputEvent_AxisType} type. For a mouse wheel event, only AXIS_TYPE_SCROLL_VERTICAL
is supported. InputEvent_AxisType_AXIS_TYPE_PINCH Pinch axis, which is used to describe a two-finger pinch gesture on the touchpad.
@since 12 InputEvent_AxisType_AXIS_TYPE_ROTATE Rotation axis, which is used to describe a two-finger rotation gesture on the touchpad.
@since 12 InputEvent_AxisType_AXIS_TYPE_SCROLL_HORIZONTAL Horizontal scroll axis. When you scroll the mouse wheel or slide with two fingers on the touchpad, the status of
the horizontal scroll axis changes.
@since 12 InputEvent_AxisType_AXIS_TYPE_SCROLL_VERTICAL Vertical scroll axis. When you scroll the mouse wheel or slide with one or two fingers on the touchpad, the
status of the vertical scroll axis changes.
@since 12 InputEvent_AxisType_AXIS_TYPE_UNKNOWN Unknown axis type, which is usually used as the initial value.
@since 12 InputEvent_MouseAxis_MOUSE_AXIS_SCROLL_HORIZONTAL Horizontal scroll axis. InputEvent_MouseAxis_MOUSE_AXIS_SCROLL_VERTICAL Vertical scroll axis. InputEvent_SourceType_SOURCE_TYPE_MOUSE Source that generates events similar to mouse pointer movement, button press and release, and wheel scrolling.
@since 12 InputEvent_SourceType_SOURCE_TYPE_TOUCHPAD Source that generates a touchpad multi-touch event.
@since 12 InputEvent_SourceType_SOURCE_TYPE_TOUCHSCREEN Source that generates a touchscreen multi-touch event.
@since 12 Input_KeyCode_KEYCODE_0 Key 0 Input_KeyCode_KEYCODE_1 Key 1 Input_KeyCode_KEYCODE_2 Key 2 Input_KeyCode_KEYCODE_3 Key 3 Input_KeyCode_KEYCODE_4 Key 4 Input_KeyCode_KEYCODE_5 Key 5 Input_KeyCode_KEYCODE_6 Key 6 Input_KeyCode_KEYCODE_7 Key 7 Input_KeyCode_KEYCODE_8 Key 8 Input_KeyCode_KEYCODE_9 Key 9 Input_KeyCode_KEYCODE_A Key A Input_KeyCode_KEYCODE_ALT_LEFT Left Alt key Input_KeyCode_KEYCODE_ALT_RIGHT Right Alt key Input_KeyCode_KEYCODE_APOSTROPHE Key ’ Input_KeyCode_KEYCODE_AT Key @ Input_KeyCode_KEYCODE_B Key B Input_KeyCode_KEYCODE_BACKSLASH Key | Input_KeyCode_KEYCODE_BREAK Break/Pause key Input_KeyCode_KEYCODE_BRIGHTNESS_DOWN Brightness Down key Input_KeyCode_KEYCODE_BRIGHTNESS_UP Brightness Up key Input_KeyCode_KEYCODE_C Key C Input_KeyCode_KEYCODE_CAMERA Camera key Input_KeyCode_KEYCODE_CAPS_LOCK Caps Lock key Input_KeyCode_KEYCODE_COMMA Key , Input_KeyCode_KEYCODE_CTRL_LEFT Left Ctrl key Input_KeyCode_KEYCODE_CTRL_RIGHT Right Ctrl key Input_KeyCode_KEYCODE_D Key D Input_KeyCode_KEYCODE_DEL Delete key Input_KeyCode_KEYCODE_DPAD_CENTER Center key on D-pad Input_KeyCode_KEYCODE_DPAD_DOWN Down key on D-pad Input_KeyCode_KEYCODE_DPAD_LEFT Left key on D-pad Input_KeyCode_KEYCODE_DPAD_RIGHT Right key on D-pad Input_KeyCode_KEYCODE_DPAD_UP Up key on D-pad Input_KeyCode_KEYCODE_E Key E Input_KeyCode_KEYCODE_ENTER Enter key Input_KeyCode_KEYCODE_ENVELOPE Email function key, used to launch the email application. Input_KeyCode_KEYCODE_EQUALS Key = Input_KeyCode_KEYCODE_ESCAPE Esc key Input_KeyCode_KEYCODE_EXPLORER Browser function key, used to launch the browser application. Input_KeyCode_KEYCODE_F Key F Input_KeyCode_KEYCODE_F1 F1 key Input_KeyCode_KEYCODE_F2 F2 key Input_KeyCode_KEYCODE_F3 F3 key Input_KeyCode_KEYCODE_F4 F4 key Input_KeyCode_KEYCODE_F5 F5 key Input_KeyCode_KEYCODE_F6 F6 key Input_KeyCode_KEYCODE_F7 F7 key Input_KeyCode_KEYCODE_F8 F8 key Input_KeyCode_KEYCODE_F9 F9 key Input_KeyCode_KEYCODE_F10 F10 key Input_KeyCode_KEYCODE_F11 F11 key Input_KeyCode_KEYCODE_F12 F12 key Input_KeyCode_KEYCODE_FN Function (Fn) key Input_KeyCode_KEYCODE_FORWARD Forward key Input_KeyCode_KEYCODE_FORWARD_DEL Forward Delete key Input_KeyCode_KEYCODE_FUNCTION Function key Input_KeyCode_KEYCODE_G Key G Input_KeyCode_KEYCODE_GRAVE Key * Input_KeyCode_KEYCODE_H Key H Input_KeyCode_KEYCODE_I Key I Input_KeyCode_KEYCODE_INSERT Insert key Input_KeyCode_KEYCODE_J Key J Input_KeyCode_KEYCODE_K Key K Input_KeyCode_KEYCODE_L Key L Input_KeyCode_KEYCODE_LEFT_BRACKET Key [ Input_KeyCode_KEYCODE_M Key M Input_KeyCode_KEYCODE_MEDIA_CLOSE Media: Close key Input_KeyCode_KEYCODE_MEDIA_EJECT Media: Reject key Input_KeyCode_KEYCODE_MEDIA_PAUSE Media: Pause key Input_KeyCode_KEYCODE_MEDIA_PLAY Media: Play key Input_KeyCode_KEYCODE_MEDIA_RECORD Media: Record key Input_KeyCode_KEYCODE_MENU Menu key Input_KeyCode_KEYCODE_META_LEFT Left Meta key Input_KeyCode_KEYCODE_META_RIGHT Right Meta key Input_KeyCode_KEYCODE_MINUS Key - Input_KeyCode_KEYCODE_MOVE_END Move to End key Input_KeyCode_KEYCODE_MOVE_HOME Move to Home key Input_KeyCode_KEYCODE_MUTE Mute key Input_KeyCode_KEYCODE_N Key N Input_KeyCode_KEYCODE_NUMPAD_0 Key 0 on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_1 Key 1 on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_2 Key 2 on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_3 Key 3 on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_4 Key 4 on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_5 Key 5 on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_6 Key 6 on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_7 Key 7 on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_8 Key 8 on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_9 Key 9 on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_ADD Key + on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_COMMA Key , on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_DIVIDE Key / on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_DOT Key . on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_ENTER Enter key on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_EQUALS Key = on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_LEFT_PAREN Key ( on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_MULTIPLY Key * on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_RIGHT_PAREN Key ) on numeric keypad Input_KeyCode_KEYCODE_NUMPAD_SUBTRACT Key - on numeric keypad Input_KeyCode_KEYCODE_NUM_LOCK Number Lock key Input_KeyCode_KEYCODE_O Key O Input_KeyCode_KEYCODE_P Key P Input_KeyCode_KEYCODE_PAGE_DOWN Page Down key Input_KeyCode_KEYCODE_PAGE_UP Page Up key Input_KeyCode_KEYCODE_PERIOD Key . Input_KeyCode_KEYCODE_PLUS Key + Input_KeyCode_KEYCODE_POUND Key # Input_KeyCode_KEYCODE_POWER Power key Input_KeyCode_KEYCODE_Q Key Q Input_KeyCode_KEYCODE_R Key R Input_KeyCode_KEYCODE_RIGHT_BRACKET Key ] Input_KeyCode_KEYCODE_S Key S Input_KeyCode_KEYCODE_SCROLL_LOCK Scroll Lock key Input_KeyCode_KEYCODE_SEMICOLON Key ; Input_KeyCode_KEYCODE_SHIFT_LEFT Left Shift key Input_KeyCode_KEYCODE_SHIFT_RIGHT Right Shift key Input_KeyCode_KEYCODE_SLASH Key / Input_KeyCode_KEYCODE_SPACE Space key Input_KeyCode_KEYCODE_STAR Key * Input_KeyCode_KEYCODE_SYM Symbol key Input_KeyCode_KEYCODE_SYSRQ System Request/Print Screen key Input_KeyCode_KEYCODE_T Key T Input_KeyCode_KEYCODE_TAB Tab key Input_KeyCode_KEYCODE_U Key U Input_KeyCode_KEYCODE_UNKNOWN Unknown key Input_KeyCode_KEYCODE_V Key V Input_KeyCode_KEYCODE_VOLUME_DOWN Volume Down key Input_KeyCode_KEYCODE_VOLUME_MUTE Speaker Mute key Input_KeyCode_KEYCODE_VOLUME_UP Volume Up key Input_KeyCode_KEYCODE_W Key W Input_KeyCode_KEYCODE_X Key X Input_KeyCode_KEYCODE_Y Key Y Input_KeyCode_KEYCODE_Z Key Z Input_KeyEventAction_KEY_ACTION_CANCEL Button action canceled. Input_KeyEventAction_KEY_ACTION_DOWN Key press. Input_KeyEventAction_KEY_ACTION_UP Key release. Input_KeyStateAction_KEY_DEFAULT Default state. Input_KeyStateAction_KEY_PRESSED Key press. Input_KeyStateAction_KEY_RELEASED Key release. Input_KeyStateAction_KEY_SWITCH_OFF Key switch disabled. Input_KeyStateAction_KEY_SWITCH_ON Key switch enabled. Input_MouseEventAction_MOUSE_ACTION_AXIS_BEGIN Beginning of the mouse axis event. Input_MouseEventAction_MOUSE_ACTION_AXIS_END End of the mouse axis event. Input_MouseEventAction_MOUSE_ACTION_AXIS_UPDATE Updating of the mouse axis event. Input_MouseEventAction_MOUSE_ACTION_BUTTON_DOWN Pressing of the mouse button. Input_MouseEventAction_MOUSE_ACTION_BUTTON_UP Release of the mouse button. Input_MouseEventAction_MOUSE_ACTION_CANCEL Cancellation of the mouse action. Input_MouseEventAction_MOUSE_ACTION_MOVE Moving of the mouse pointer. Input_MouseEventButton_MOUSE_BUTTON_BACK Back button. Input_MouseEventButton_MOUSE_BUTTON_FORWARD Forward button. Input_MouseEventButton_MOUSE_BUTTON_LEFT Left button. Input_MouseEventButton_MOUSE_BUTTON_MIDDLE Middle button. Input_MouseEventButton_MOUSE_BUTTON_NONE Invalid button. Input_MouseEventButton_MOUSE_BUTTON_RIGHT Right button. Input_Result_INPUT_DEVICE_NOT_SUPPORTED Function not supported. Input_Result_INPUT_NOT_SYSTEM_APPLICATION Non-system application. Input_Result_INPUT_PARAMETER_ERROR Parameter check fails. Input_Result_INPUT_PERMISSION_DENIED Permission verification failed. Input_Result_INPUT_REPEAT_INTERCEPTOR Interceptor repeatedly created. Input_Result_INPUT_SERVICE_EXCEPTION Service error. Input_Result_INPUT_SUCCESS Operation succeeded. Input_TouchEventAction_TOUCH_ACTION_CANCEL Touch cancellation. Input_TouchEventAction_TOUCH_ACTION_DOWN Touch press. Input_TouchEventAction_TOUCH_ACTION_MOVE Touch moving. Input_TouchEventAction_TOUCH_ACTION_UP Touch release. OH_Input_AddAxisEventMonitor ⚠ @brief Adds a listener for the specified type of axis events, which are defined in {@link InputEvent_AxisEventType}. OH_Input_AddAxisEventMonitorForAll ⚠ @brief Adds a listener for all types of axis events, which are defined in {@link InputEvent_AxisEventType}. OH_Input_AddInputEventInterceptor ⚠ @brief Adds an interceptor for input events, including mouse, touch, and axis events. Only the first addition takes
effect. Subsequent requests will return error code {@link INPUT_REPEAT_INTERCEPTOR}. Key events are intercepted only
when the application window is hit. OH_Input_AddKeyEventInterceptor ⚠ @brief Adds a key event interceptor. Only the first addition takes effect. Subsequent requests will return error
code {@link INPUT_REPEAT_INTERCEPTOR}. Key events are intercepted only when the application gains focus. OH_Input_AddKeyEventMonitor ⚠ @brief Adds a listener for key events. Only the initial addition takes effect. Subsequent attempts will be ignored. OH_Input_AddMouseEventMonitor ⚠ @brief Adds a listener for mouse events, including mouse click and movement events, but not scroll wheel events.
Scroll wheel events are axis events.
This API can be called only when the screen recording scenario is in use. Otherwise, the call does not take
effect. OH_Input_AddTouchEventMonitor ⚠ @brief Adds a listener for touch input events. OH_Input_CancelInjection ⚠ @brief Stops event injection and revokes authorization. OH_Input_CreateAxisEvent ⚠ @brief Creates an axis event object. You can call {@link OH_Input_DestroyAxisEvent()} to destroy an axis event
object. OH_Input_CreateKeyEvent ⚠ @brief Creates a key event object. You can call {@link OH_Input_DestroyKeyEvent()} to destroy a key event object. OH_Input_CreateKeyState ⚠ @brief Creates a key status enum object. You can call {@link OH_Input_DestroyKeyState()} to destroy a key status
enum object. OH_Input_CreateMouseEvent ⚠ @brief Creates a mouse event object. You can call {@link OH_Input_DestroyMouseEvent()} to destroy a mouse event
object. OH_Input_CreateTouchEvent ⚠ @brief Creates a TouchEvent object. You can call {@link OH_Input_DestroyTouchEvent()} to destroy a touch event
object. OH_Input_DestroyAxisEvent ⚠ @brief Destroys an axis event object. OH_Input_DestroyKeyEvent ⚠ @brief Destroys a key event object. OH_Input_DestroyKeyState ⚠ @brief Destroys a key status enum object. OH_Input_DestroyMouseEvent ⚠ @brief Destroys a mouse event object. OH_Input_DestroyTouchEvent ⚠ @brief Destroys a TouchEvent object. OH_Input_GetAxisEventAction ⚠ @brief Obtains the action of an axis event. OH_Input_GetAxisEventActionTime ⚠ @brief Obtains the time when an axis event occurs. OH_Input_GetAxisEventAxisValue ⚠ @brief Obtains the axis value for the specified axis type of the axis event. OH_Input_GetAxisEventDisplayX ⚠ @brief Obtains the X coordinate of the axis event in the relative coordinate system with the upper-left corner of
the specified screen as the origin. OH_Input_GetAxisEventDisplayY ⚠ @brief Obtains the Y coordinate of the axis event in the relative coordinate system with the upper-left corner of
the specified screen as the origin. OH_Input_GetAxisEventSourceType ⚠ @brief Obtains the axis event source type. OH_Input_GetAxisEventType ⚠ @brief Obtains the axis event type. OH_Input_GetKeyCode ⚠ @brief Obtains the key value of a key status enum object. OH_Input_GetKeyEventAction ⚠ @brief Obtains the key event action. OH_Input_GetKeyEventActionTime ⚠ @brief Obtains the time when a key event occurs. OH_Input_GetKeyEventKeyCode ⚠ @brief Obtains the key code value of a key event. OH_Input_GetKeyPressed ⚠ @brief Checks whether the key specific to a key status enum object is pressed. OH_Input_GetKeyState ⚠ @brief Queries a key status enum object. OH_Input_GetKeySwitch ⚠ @brief Obtains the key switch of the key status enum object. OH_Input_GetMouseEventAction ⚠ @brief Obtains the action of a mouse event. OH_Input_GetMouseEventActionTime ⚠ @brief Obtains the time when a mouse event occurs. OH_Input_GetMouseEventAxisType ⚠ @brief Obtains the axis type of a mouse event. OH_Input_GetMouseEventAxisValue ⚠ @brief Obtains the axis value of a mouse axis event. OH_Input_GetMouseEventButton ⚠ @brief Obtains the button of a mouse event. OH_Input_GetMouseEventDisplayX ⚠ @brief Obtains the X coordinate of the mouse event in the relative coordinate system with the upper-left corner of
the specified screen as the origin. OH_Input_GetMouseEventDisplayY ⚠ @brief Obtains the Y coordinate of the mouse event in the relative coordinate system with the upper-left corner of
the specified screen as the origin. OH_Input_GetTouchEventAction ⚠ @brief Obtains the action of a touch event. OH_Input_GetTouchEventActionTime ⚠ @brief Obtains the time when the touch event occurs. OH_Input_GetTouchEventDisplayX ⚠ @brief Obtains the X coordinate of the touch event in the relative coordinate system with the upper-left corner of
the specified screen as the origin. OH_Input_GetTouchEventDisplayY ⚠ @brief Obtains the Y coordinate of the touch event in the relative coordinate system with the upper-left corner of
the specified screen as the origin. OH_Input_GetTouchEventFingerId ⚠ @brief Obtains the finger ID of a touch event. OH_Input_InjectKeyEvent ⚠ @brief Injects a key event.
This API does not take effect if the user has not granted authorization and the caller does not have the ohos.
permission.CONTROL_DEVICE permission.
Since API version 20, you are advised to use {@link OH_Input_RequestInjection()} to request the required
permission before calling this API. If the status returned by {@link OH_Input_QueryAuthorizedStatus()} is
{@link AUTHORIZED}, then you can call this API.
Since API version 22, if the key press event (KEY_ACTION_DOWN ) of a modifier key (KEYCODE_META_LEFT , **
KEYCODE_META_RIGHT**, KEYCODE_CTRL_LEFT , KEYCODE_CTRL_RIGHT , KEYCODE_ALT_LEFT , KEYCODE_ALT_RIGHT , **
KEYCODE_SHIFT_LEFT**, KEYCODE_SHIFT_RIGHT , KEYCODE_CAPS_LOCK , KEYCODE_SCROLL_LOCK , or *KEYCODE_NUM_LOCK
*) is injected, the release event (KEY_ACTION_UP ) of the key needs to be injected in a timely manner to avoid
the key being pressed for a long time.
Since API version 26.0.0, callers that have the ohos.permission.CONTROL_DEVICE permission can use this API
directly. OH_Input_InjectMouseEvent ⚠ @brief Injects a mouse event by using coordinates in the relative coordinate system with the upper-left corner of
the specified screen as the origin.
This API does not take effect if the user has not granted authorization and the caller does not have the ohos.
permission.CONTROL_DEVICE permission.
Since API version 20, you are advised to use {@link OH_Input_RequestInjection()} to request the required
permission before calling this API. If the status returned by {@link OH_Input_QueryAuthorizedStatus()} is
{@link AUTHORIZED}, then you can call this API.
Since API version 26.0.0, callers that have the ohos.permission.CONTROL_DEVICE permission can use this API
directly. OH_Input_InjectTouchEvent ⚠ @brief Injects a touch event by using coordinates in the relative coordinate system with the upper-left corner of
the specified screen as the origin.
This API does not take effect if the user has not granted authorization and the caller does not have the ohos.
permission.CONTROL_DEVICE permission.
Since API version 20, you are advised to use {@link OH_Input_RequestInjection()} to request the required
permission before calling this API. If the status returned by {@link OH_Input_QueryAuthorizedStatus()} is
{@link AUTHORIZED}, then you can call this API.
Since API version 26.0.0, callers that have the ohos.permission.CONTROL_DEVICE permission can use this API
directly. OH_Input_RemoveAxisEventMonitor ⚠ @brief Removes the listener for the specified type of axis events, which are defined in
{@link InputEvent_AxisEventType}. OH_Input_RemoveAxisEventMonitorForAll ⚠ @brief Removes the listener for all types of axis events. OH_Input_RemoveInputEventInterceptor ⚠ @brief Removes the interceptor for input events, including mouse, touch, and axis events. OH_Input_RemoveKeyEventInterceptor ⚠ @brief Removes the interceptor for key events. OH_Input_RemoveKeyEventMonitor ⚠ @brief Removes the listener for key events. OH_Input_RemoveMouseEventMonitor ⚠ @brief Removes the listener for mouse events. OH_Input_RemoveTouchEventMonitor ⚠ @brief Removes the listener for touch events. OH_Input_SetAxisEventAction ⚠ @brief Sets the action for an axis event. OH_Input_SetAxisEventActionTime ⚠ @brief Sets the time when an axis event occurs. OH_Input_SetAxisEventAxisValue ⚠ @brief Sets the axis value of the axis type specified by the axis event. OH_Input_SetAxisEventDisplayX ⚠ @brief Sets the X coordinate of the axis event in the relative coordinate system with the upper-left corner of the
specified screen as the origin. OH_Input_SetAxisEventDisplayY ⚠ @brief Sets the Y coordinate of the axis event in the relative coordinate system with the upper-left corner of the
specified screen as the origin. OH_Input_SetAxisEventSourceType ⚠ @brief Sets the axis event source type. OH_Input_SetAxisEventType ⚠ @brief Sets the axis event type. OH_Input_SetKeyCode ⚠ @brief Sets the key value of a key status enum object. OH_Input_SetKeyEventAction ⚠ @brief Sets the key event type. OH_Input_SetKeyEventActionTime ⚠ @brief Sets the time when a key event occurs. OH_Input_SetKeyEventKeyCode ⚠ @brief Sets the key code value for a key event. OH_Input_SetKeyPressed ⚠ @brief Sets whether the key specific to a key status enum object is pressed. OH_Input_SetKeySwitch ⚠ @brief Sets the key switch of the key status enum object. OH_Input_SetMouseEventAction ⚠ @brief Sets the action for a mouse event. OH_Input_SetMouseEventActionTime ⚠ @brief Sets the time when a mouse event occurs. OH_Input_SetMouseEventAxisType ⚠ @brief Sets the axis type for a mouse event. OH_Input_SetMouseEventAxisValue ⚠ @brief Sets the axis value for a mouse axis event. OH_Input_SetMouseEventButton ⚠ @brief Sets the button for a mouse event. OH_Input_SetMouseEventDisplayX ⚠ @brief Sets the X coordinate of the mouse event in the relative coordinate system with the upper-left corner of the
specified screen as the origin. OH_Input_SetMouseEventDisplayY ⚠ @brief Sets the Y coordinate of the mouse event in the relative coordinate system with the upper-left corner of the
specified screen as the origin. OH_Input_SetTouchEventAction ⚠ @brief Sets the action of a touch event. OH_Input_SetTouchEventActionTime ⚠ @brief Sets the time when the touch event occurs. OH_Input_SetTouchEventDisplayX ⚠ @brief Sets the X coordinate of the touch event in the relative coordinate system with the upper-left corner of the
specified screen as the origin. OH_Input_SetTouchEventDisplayY ⚠ @brief Sets the Y coordinate of the touch event in the relative coordinate system with the upper-left corner of the
specified screen as the origin. OH_Input_SetTouchEventFingerId ⚠ @brief Sets the finger ID of a touch event. InputEvent_AxisAction @brief Action of the input device. InputEvent_AxisEventType @brief Event type of the input device. InputEvent_AxisType @brief Defines the axis type of an input device. InputEvent_MouseAxis @brief Provides the enum values of mouse axis event types. InputEvent_SourceType @brief Provides the enum values of event source types. Input_AxisEventCallback @brief Defines a lifecycle callback for axisEvent . If the callback is triggered, axisEvent will be destroyed. Input_KeyCode @brief Enumerates the key codes. Input_KeyEventAction @brief Provides the enum values of the key event type. Input_KeyEventCallback @brief Defines a lifecycle callback for keyEvent . If the callback is triggered, keyEvent will be destroyed. Input_KeyStateAction @brief Provides the enum values of the key status. Input_MouseEventAction @brief Provides the enum values of mouse actions. Input_MouseEventButton @brief Provides the enum values of mouse buttons. Input_MouseEventCallback @brief Defines a lifecycle callback for mouseEvent . If the callback is triggered, mouseEvent will be
destroyed. Input_Result @brief Provides return value enumerations. Input_TouchEventAction @brief Provides the enum values of touch actions. Input_TouchEventCallback @brief Defines the lifecycle callback for TouchEvent . If the callback is triggered, TouchEvent will be
destroyed.