pub unsafe extern "C" fn OH_Input_GetKeyEventKeyCode(
keyEvent: *const Input_KeyEvent,
) -> i32Expand description
@brief Obtains the key code value of a key event.
@param keyEvent KeyEvent object, which can be created through {@link OH_Input_CreateKeyEvent()}.
If the key event object is no longer needed, destroy it by calling {@link OH_Input_DestroyKeyEvent()}.
@return Key code of a key event. For details, see {@link Input_KeyCode}.
@syscap SystemCapability.MultimodalInput.Input.Core
@since 12