pub unsafe extern "C" fn OH_Input_GetKeySwitch(
keyState: *const Input_KeyState,
) -> i32Expand description
@brief Obtains the key switch of the key status enum object.
@param keyState Key status enum object. For details, see {@link Input_KeyStateAction}. @return Key switch of the key status enum object. For details, see {@link Input_KeyStateAction}. @syscap SystemCapability.MultimodalInput.Input.Core @since 12