pub unsafe extern "C" fn OH_Input_SetAxisEventActionTime(
axisEvent: *mut Input_AxisEvent,
actionTime: i64,
) -> Input_ResultExpand description
@brief Sets the time when an axis event occurs.
@param axisEvent Axis event object. You can call {@link OH_Input_CreateAxisEvent()} to create an axis event object.
If the axis event object is no longer needed, destroy it by calling {@link OH_Input_DestroyAxisEvent()}.
@param actionTime Time when the axis event occurred, representing the number of microseconds elapsed since system
startup, in microseconds (μs).
@return {@link INPUT_SUCCESS} if the operation is successful; {@link INPUT_PARAMETER_ERROR} if axisEvent is null.
@syscap SystemCapability.MultimodalInput.Input.Core
@since 12