pub unsafe extern "C" fn OH_Input_SetAxisEventDisplayY(
axisEvent: *mut Input_AxisEvent,
displayY: f32,
) -> Input_ResultExpand description
@brief Sets the Y coordinate of the axis event in the relative coordinate system with the upper-left corner of the specified screen as the origin.
@param axisEvent Axis event object. You can call {@link OH_Input_CreateAxisEvent()} to create an axis event object.
If the axis event object is no longer needed, destroy it by calling {@link OH_Input_DestroyAxisEvent()}.
@param displayY Y coordinate in the relative coordinate system with the upper left corner of the specified screen as
the origin, in pixels (px).
@return {@link INPUT_SUCCESS} if the operation is successful; {@link INPUT_PARAMETER_ERROR} if axisEvent is null.
@syscap SystemCapability.MultimodalInput.Input.Core
@since 12