pub unsafe extern "C" fn OH_Input_SetKeyEventActionTime(
keyEvent: *mut Input_KeyEvent,
actionTime: i64,
)Expand description
@brief Sets the time when a key event occurs.
@param keyEvent KeyEvent object, which can be created through {@link OH_Input_CreateKeyEvent()}.
If the key event object is no longer needed, destroy it by calling {@link OH_Input_DestroyKeyEvent()}.
@param actionTime Time when the key event occurred, representing the number of microseconds elapsed since system
startup, in microseconds (μs).
@syscap SystemCapability.MultimodalInput.Input.Core
@since 12