pub unsafe extern "C" fn OH_Input_SetMouseEventAxisValue(
mouseEvent: *mut Input_MouseEvent,
axisValue: f32,
)Expand description
@brief Sets the axis value for a mouse axis event.
@param mouseEvent Mouse event object. You can call {@link OH_Input_CreateMouseEvent()} to create a mouse event
object.
If the mouse event object is no longer needed, destroy it by calling {@link OH_Input_DestroyMouseEvent()}.
@param axisValue Axis event value. A positive number means scrolling forward (for example, 1.0 equals one unit
forward), and a negative number means scrolling backward (for example, -1.0 equals one unit backward).
@syscap SystemCapability.MultimodalInput.Input.Core
@since 12