pub unsafe extern "C" fn OH_Input_SetMouseEventDisplayX(
mouseEvent: *mut Input_MouseEvent,
displayX: i32,
)Expand description
@brief Sets the X coordinate of the mouse event in the relative coordinate system with the upper-left corner of the specified screen as the origin.
@param mouseEvent Mouse event object. You can call {@link OH_Input_CreateMouseEvent()} to create a mouse event
object.
If the mouse event object is no longer needed, destroy it by calling {@link OH_Input_DestroyMouseEvent()}.
@param displayX X-coordinate in the relative coordinate system with the upper left corner of the specified screen as
the origin, in pixels (px).
@syscap SystemCapability.MultimodalInput.Input.Core
@since 12